#
# spec file for package python-limnoria
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-limnoria
Version:        2025.5.3
Release:        1.1
Summary:        A modified version of Supybot (an IRC bot and framework)
License:        BSD-3-Clause
URL:            https://github.com/ProgVal/Limnoria
Source:         https://files.pythonhosted.org/packages/source/l/limnoria/limnoria-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Skip Fediverse webfinger tests that don't seem to mock correctly
Patch0:         skip-fediverse-profile-tests.patch
# full python for sqlite3 module
BuildRequires:  %pythons
BuildRequires:  %{python_module PySocks}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module ecdsa}
BuildRequires:  %{python_module feedparser}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module python-gnupg}
BuildRequires:  %{python_module pytzdata}
# pyxmpp2-scram not available, the code actually covers the non-availability
#BuildRequires:  %%{python_module pyxmpp2-scram}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  coreutils-systemd
BuildRequires:  fdupes
BuildRequires:  procps
BuildRequires:  python-rpm-macros
Requires:       procps
Requires:       python
Requires:       python-PySocks
Requires:       python-chardet
Requires:       python-cryptography
Requires:       python-ecdsa
Requires:       python-feedparser
Requires:       python-python-dateutil
Requires:       python-python-gnupg
Requires:       python-pytzdata
#Requires:       python-pyxmpp2-scram
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       Supybot = %{version}
Obsoletes:      Supybot < 1.0
BuildArch:      noarch
%python_subpackages

%description
Limnoria is a Python IRC bot with a plugin API. It is equipped with
an ACL system for specifying user permissions with per-command
granularity. Numerous plugins are included.

%prep
%autosetup -p1 -n limnoria-%{version}
sed -i "1,4{/\/usr\/bin\/python/d}" plugins/Debug/plugin.py
sed -i "1,4{/\/usr\/bin\/env/d}" plugins/SedRegex/constants.py

sed -Ei "1{\@^#!/usr/bin/env python3@d}" src/scripts/limnoria_*.py

%build
# Get SOURCE_DATE_EPOCH corresponding to pyproject.toml in sources
export SOURCE_DATE_EPOCH=`date -r pyproject.toml +"%s"`
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/supybot/
for ex in supybot limnoria
do
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}.1
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}-adduser.1
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}-botchk.1
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}-plugin-create.1
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}-plugin-doc.1
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}-test.1
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}-wizard.1
  %python_clone -a %{buildroot}%{_mandir}/man1/${ex}-reset-password.1
  %python_clone -a %{buildroot}%{_bindir}/${ex}
  %python_clone -a %{buildroot}%{_bindir}/${ex}-adduser
  %python_clone -a %{buildroot}%{_bindir}/${ex}-botchk
  %python_clone -a %{buildroot}%{_bindir}/${ex}-plugin-create
  %python_clone -a %{buildroot}%{_bindir}/${ex}-plugin-doc
  %python_clone -a %{buildroot}%{_bindir}/${ex}-reset-password
  %python_clone -a %{buildroot}%{_bindir}/${ex}-test
  %python_clone -a %{buildroot}%{_bindir}/${ex}-wizard
done

%fdupes %{buildroot}%{_mandir}/man1/

%check
%{python_expand export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}%{$python_sitelib}/
# Status plugin cannot read cpuinfo in obs environment
%{buildroot}%{_bindir}/supybot-test-%{$python_bin_suffix} -c -v --plugins-dir=%{buildroot}%{$python_sitelib}/supybot/plugins/ --no-network
}

%post
%{python_install_alternative supybot supybot-adduser supybot-botchk
  supybot-plugin-create supybot-plugin-doc supybot-reset-password supybot-test supybot-wizard
  supybot.1 supybot-adduser.1 supybot-botchk.1 supybot-plugin-create.1
  supybot-plugin-doc.1 supybot-reset-password.1 supybot-test.1 supybot-wizard.1
  limnoria limnoria-adduser limnoria-botchk
  limnoria-plugin-create limnoria-plugin-doc limnoria-reset-password limnoria-test limnoria-wizard
  limnoria.1 limnoria-adduser.1 limnoria-botchk.1 limnoria-plugin-create.1
  limnoria-plugin-doc.1 limnoria-reset-password.1 limnoria-test.1 limnoria-wizard.1
}

%postun
%{python_uninstall_alternative supybot limnoria}

%files %{python_files}
%doc README.md
%license LICENSE.md
%python_alternative %{_bindir}/limnoria
%python_alternative %{_bindir}/limnoria-adduser
%python_alternative %{_bindir}/limnoria-botchk
%python_alternative %{_bindir}/limnoria-plugin-create
%python_alternative %{_bindir}/limnoria-plugin-doc
%python_alternative %{_bindir}/limnoria-reset-password
%python_alternative %{_bindir}/limnoria-test
%python_alternative %{_bindir}/limnoria-wizard
%python_alternative %{_bindir}/supybot
%python_alternative %{_bindir}/supybot-adduser
%python_alternative %{_bindir}/supybot-botchk
%python_alternative %{_bindir}/supybot-plugin-create
%python_alternative %{_bindir}/supybot-plugin-doc
%python_alternative %{_bindir}/supybot-reset-password
%python_alternative %{_bindir}/supybot-test
%python_alternative %{_bindir}/supybot-wizard
%python_alternative %{_mandir}/man1/limnoria.1
%python_alternative %{_mandir}/man1/limnoria-adduser.1
%python_alternative %{_mandir}/man1/limnoria-botchk.1
%python_alternative %{_mandir}/man1/limnoria-plugin-create.1
%python_alternative %{_mandir}/man1/limnoria-plugin-doc.1
%python_alternative %{_mandir}/man1/limnoria-reset-password.1
%python_alternative %{_mandir}/man1/limnoria-test.1
%python_alternative %{_mandir}/man1/limnoria-wizard.1
%python_alternative %{_mandir}/man1/supybot.1
%python_alternative %{_mandir}/man1/supybot-adduser.1
%python_alternative %{_mandir}/man1/supybot-botchk.1
%python_alternative %{_mandir}/man1/supybot-plugin-create.1
%python_alternative %{_mandir}/man1/supybot-plugin-doc.1
%python_alternative %{_mandir}/man1/supybot-reset-password.1
%python_alternative %{_mandir}/man1/supybot-test.1
%python_alternative %{_mandir}/man1/supybot-wizard.1
%{python_sitelib}/supybot/
%{python_sitelib}/limnoria-%{version}*.*-info

%changelog
* Sun May  4 2025 Dirk Müller <dmueller@suse.com>
- update to 2025.5.3:
  * Fix compatibility with setuptools >= 80
  * registry.Json: Fix serialization/deserialization points
  * Make supybot.plugins.Web.urlWhitelist channel-specific
  * Fix interference of wrap() and internationalizeDocstring()
  * Add support for Python 3.14.0-alpha1
  * i18n: Remove hacks for Python 2
  * Add support for negative integers options following getopt
* Thu Jan  2 2025 Atri Bhattacharya <badshah400@gmail.com>
- Fix dist-info versioning by exporting the correct
  SOURCE_DATE_EPOCH before building.
- Revert changes from previous commit in lieu of current, better
  fix.
* Thu Jan  2 2025 Atri Bhattacharya <badshah400@gmail.com>
- Account for the dist-info version differing from tarball version
  in file lists.
* Tue Dec 10 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2024.10.19:
  * Add IrcState.nicksToAccount
  * core & Channel: Add option --account to kban and iban
  * Add support for 'account' in supybot.protocols.irc.banmask
  * Replace makeExtBanmask with makeExtBanmasks
  * makeExtBanmasks: Log invalid options
  * requirements.txt: add ddate as an optional dependency for Time.ddate
  * Socket: Fix hanging while TLS socket buffer is non-empty
  * Debug: Remove useless shebang
  * httpserver: Fix incorrect path joining
  * RSS: Add support for $content/$summary_detail/$title_detail
  * RSS: Copy $summary to $description on Atom feeds
  * Fix recursive loop in limnoria_reset_password
  * Geography: Add support for OSM node ids
  * Web: Fix crash on trailing ';' in Content-Type
  * Web: Fix crash on socket.timeout on snarfed URLs
  * Fediverse: Catch URLErrors raised when checking webfinger support
  * Services: Improve error on missing password or NickServ nick
  * Changed whois provider domain to whois.iana.org
  * RSS: Update link to feedparser
  * ircdb.checkIgnored: return False for messages from servers
  * RSS: Don't log tracebacks for HTTP errors
  * Create temporary files in a temporary directory
  * Channel: Fix error in when channel is configured but not joined
  * Web: Need to download even more Javascript from Youtube
  * Admin: Fix leftover state change in testPart
  * Admin: Actually clean up test channel from configuration
  * Fix SyntaxWarning on Python 3.12
  * httpserver: Rewrite without the cgi module
  * Internet: Use socket directly instead of telnetlib
  * Unix: Disable 'crypt' command on Python >= 3.13
  * RSS: Fix error when re-creating a feed with a different name
  * Add per-network 'vhost' and 'vhostv6' config variables
  * Misc: update version fetching to the new branches
  * safeEval: Fix support for Python 3.14
  * GPG: Import documentation removed from the Getting Started guide
  * Cowardly refuse to ban oneself with an account extban
  * Fall back to banning host instead of exact mask
  * Add test the bot won't account-extban itself
  * Added russian locale to limnoria
  * Use cProfile instead of profile
  * Web: Add youtu.be to Youtube's domain list
  * plugin-doc: Prevent hyphenation of -- in command syntax
  * Add config value supybot.reply.mores.instant.whenPrivate
  * Fix NormalizedString serialization splitting within escape sequences.
  * Updated russian translation based on updated messages.pot
  * Factoids: Fix search results when single key matched
  * Unix: Fix IPv6 formating of ping command
  * Web: Add workaround for minified Reddit URLs
- Switch back to PyPi tarball.
- Switch to autosetup and pyproject macros.
- Add patch skip-fediverse-profile-tests.patch:
  * Skip some misbehaving tests.
* Fri Oct 20 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2023.09.24.2:
  * PluginDownloader: Fix typo
- List limnoria executables as part of file-list.
- Drop unnecessary hashbangs from non-exec scripts.
- Link duplicate files in man dir.
* Fri Oct 20 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add coreutils-systemd to BuildRequires for the `uptime` command
  needed for a test.
* Thu May  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2023-02-11:
  * Fix: Some instances behind Cloudflare block requests without a
    User-Agent header.
* Sat Apr 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add explicit {python_module pytzdata} BuildRequires and
  python-pytzdata Requires, needed for build in Tumbleweed now.
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022-11-16
  * Google: Remove broken commands
* Mon Oct 31 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2022-09-27:
  * utils/web: Add <br/> to the list of block elements.
* Thu Jul 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2022-07-03:
  * PluginDownloader: replace automatic 2to3 step with a simple
    warning.
* Thu Apr 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- feedparser is now available on Python 3.10, remove the skip.
* Wed Mar 23 2022 pgajdos@suse.com
- python-mock is not required for build
* Sat Mar 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2022-03-19:
  * irclib: Catch exception from outFilter, as with inFilter
* Sat Feb  5 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2022-02-03
  * wizard: Fix mixup of sasl username and password
  * Format: allow empty substrings in 'replace'.  This allows for
    easy substring removal without having to use regex.
  * setup.py + CI: Remove support for Python 3.4 and 3.5
  * Time: Fix error handling in @tztime.
  * LogToIrc: Synchronize README with config.py. Better document
    the format of the 'target' config var
  * Expose standardSubstitute's var dictionary. So it can be reused
    by plugins if they want to use a different templating engine.
  * Services: Update to the latest version of the
    draft/account-registration spec.
- Skip python310: no feedparser due to missing sgmllib3k for
  Python 3.10
- Enable the test suite
* Wed Jun 16 2021 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 2021-05-27:
  + Socket: Fix crash non-TLS connections when using a SOCKS proxy
  + Socket: Disable resolution when using a SOCKS proxy
  + drivers: Log SOCKS proxy on connecting
  + callbacks, Misc, Relay: Fix when the message prefix is just a nick
  + Admin: Fix python 3.4 support
  + ircdb: Fix 'IrcUser.nicks' on non-lowercase network names
  + Add the option to disable password login.
  + Move official channel from Freenode to Libera.Chat
  + SedRegex: Fix NameError in config setup
  + Network: Fix IPv6 parsing
  + Channel: Fix Nameerror in @Alert.
  + httpserver: Fix pointless tracebacks
  + Relay: Don't relay QUIT/NICK if the sender isn't in the relayed channel.
  + RSS: Make @remove completely clean up feeds
  + RSS: Default to setting announces per channel+network, instead of
    just per channel
  + RSS: Forbid dots in feed names.
  + Services: Keep per-network state separate
  + all plugins: regenerate READMEs
  + httpserver, Fediverse: show an error message on 404
  + Fediverse: Move Secure Fetch documentation to the 'Usage' section
  + Fix computation of message overhead in multiline batches.
  + Log loading times for each plugin
  + supybot-plugin-doc: Add labels for all command and config variables
  + callbacks: Don't write nick prefixes in the middle of multiline messages
* Mon Mar 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2021-03-17:
  * README+setup: Update supported Python versions.
* Thu Dec 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-12-07:
  * Try all IP addresses of a hostname.
* Wed Oct 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-10-13:
  * RSS: Fix announce removal to work with net+chan-specific
    config.
  * It only removed the value from the chan-specific value.
* Fri Sep  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-09-03:
  * ChannelLogger:
  - Add tests for getLog.
  - Write tests for privmsg and notice.
  - Write tests for relayed privmsg.
  - Add tests for non-relayed messages when rewriteRelayed is
    True.
* Sun Aug 30 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-08-30:
  * Herald:
  - Throttle default heralds.
  - Use time.monotonic instead of time.time.
  * DDG:
  - Fix redirect detection.
  - Add region and safeSearch configs.
  - Add region test.
  * callbacks:
  - don't crash when the prefix is from network services.
  - add comments to findCallbacksForArgs.
  * utils.net:
  - always check fingerprints if they are set, even if
    verifyCertificates is False.
  - Do not disable TLS certificate check when
    authorityCertificate is set.
  * Autocomplete:
  - Initial implementation.
  - Fix name of response tag.
  - Only return the end of the current word (or the next one if
    the current word is finished).
  - return only the common prefix + one word.
  - more readable test failures.
  - configure Black.
  * ChannelLogger:
  - Fix regression preventing outgoing messages from being logged.
  - rewrite relayed messages echoed by the server
  - Fix typo in variable name.
  - update comment
  * irclib: Don't error when 004 is missing umodes and chanmodes.
  * Selectable User-Agent for HTTP requests
    (gh#ProgVal/Limnoria#1423)
  * Fix typo. HttpUserAgent -> HttpUserAgents
    (gh#ProgVal/Limnoria#1424)
  * userAgents: avoid potential IndexError
  * Google: Set User-Agent override. (gh#ProgVal/Limnoria#1426)
  * Factoids: Add --author filtering to @search.
  * Rename IrcCallback.echo_message to IrcCallback.echoMessage.
- Use limnoria-%%{version}.ext naming scheme for source instead of
  python-limnoria-%%{version}.ext
* Thu Jul  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-07-01:
  * DDG: better document the transitions in the parser.
* Sat May  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-05-01:
  * Fix extra arguments to irc.reply() being ignored by messages
    returned by '@more' (gh#ProgVal/Limnoria#1405).
- Run an extra sed during %%setup to clean hashbang from a file not
  installed in an executable path.
- Drop the _service file, use full source URL directly allowing
  renaming of the tarball in %%{name}-%%{version} format.
* Fri Mar 27 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-03-19:
  * Update links to the documentation.
  * Updated translations.
- Use %%{name}-%%{version} naming scheme for source tarball.
* Mon Feb 10 2020 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 2020-01-31:
  + RSS: If ids are missing, use <link> as id.
  + RSS: Show a meaningful error in case '@rss' is called with a non-URL/…
  + ChannelStats: Use the safe math evaluator.
  + core/Math: Move the math evaluator to src/utils/.
  + Math: Fix log/log10 return type.
  + Aka, Google, String: fix more DeprecationWarning in tests (#1328)
  + AutoMode, Channel, Nickometer: fix invalid escape sequence Deprecatio…
  + plugins: use r'' strings to fix DeprecationWarning in test cases (#1328)
  + Aka, Debug: cleanup imports
  + Use importlib instead of imp.
  + Replace failUnless/failIf with assertTrue/assertFalse.
  + Socket: Don't add instances twice in cls._instances.
  + Socket: use a proper lock instead of a boolean.
  + Add subcommand dispatching for CAP/FAIL/WARN/NOTE.
  + Rename doAuthenticate* functions to not conflict with callback names.
  + Make irc.error do nothing is no string is given as argument.
  + Call super().setValue() before defaultHttpHeaders.
  + Deduplicate setting Accept-Language HTTP header.
  + Web: Implement protocols.http.requestLanguage
  + Add supybot.protocols.http.requestLanguage
  + Fix getSpecific usage
  + Import MutableMapping and MutableSet from collections.abc.
  + setup.py: migrate shebang to Python 3
  + setup.py: remove obsolete version_info conditionals
  + scripts: remove obsolete conditionals for Python 2
  + scripts: migrate shebangs and version checks to Python 3
  + Be less hostile to users in --allow-root help
  + Readd Limnoria name to default part & quit messages
  + SedRegex: skip testReDoSTimeout if multiprocessing is disabled
  + SedRegex: update plugin metadata
  + SedRegex: spawn a single process to handle the whole history.
  + SedRegex: add test for ReDoS timeout
  + SedRegex: abort when a search times out
  + SedRegex: test case normalization of channel names
  + SedRegex: match channel names case insensitively
  + SedRegex: log all errors, always display the not found mesage
  + SedRegex: reuse processTimeout in the sub() process too
  + SedRegex: README: specifically mention that /s is specific to this plugin
  + SedRegex: make the regexp process timeout configurable
  + SedRegex: remove compatibility workaround for Python 2.7.6 and lower
  + SedRegex: skip testBoldReplacement on Python 2
  + SedRegex: remove a duplicate test
  + SedRegex: use self.__class__ instead of __class__ in tests (Python 2 …
  + SedRegex: add a bunch of test cases
  + SedRegex: bump copyright year to 2017
  + SedRegex: fix some replacement queries not working
  + SedRegex: also catch errors in the regexp_wrapper() step
  + SedRegex: log the exact error name instead of "SedRegex error"
  + SedRegex: require ending delimiter to prevent overzealous matching of…
  + SedRegex: work around "nothing to replace" errors on < Python 2.7.6 a…
  + SedRegex: fix flag matching
  + SedRegex: add configuration / usage instructions
  + SedRegex: implement 's' regex flag to only match the caller's message
  + SedRegex: allow free form flags and return them in _unpack_sed()
  + SedRegex: sanitize against \n\r\t in output
  + SedRegex: only operate on messages from the current network
  + SedRegex: work around "nothing to repeat" errors on Python < 2.7.6
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-01-01:
  + Skip irctest when optional dependencies are not installed.
- python2 no longer supported; use skip_python2 macro to disable
  it.
* Mon Dec 30 2019 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 2019-12-21:
  + Add config supybot.reply.format.list.maximumItems to limit the size o…
  + Add fallback if getting supybot.language from registry cache failed.
  + All plugins: set Limnoria contributors as maintainer
  + Better formatting in supybot.Author if some fields are missing
  + Get locale name on startup from registry cache instead of parsing con…
  + Make getLocaleFromRegistryCache reload existing locales.
  + Math: Fix test on Pypy.
  + Math: Display a nicer error in case of MemoryError.
  + MoobotFactoids: Fix support of commands sent in private.
  + Nicer error message in getChannel/makeChannelFilename when channel is…
  + Plugin: support showing __maintainer__ field in the 'author' command
  + Plugin: accept author name in 'contributors' command
  + QuoteGrabs: fix SyntaxWarning (#1391)
  + Remove dead code from Group that belongs in Value.
  + Request msgid capability.
  + RSS: Register feed config in config.py instead of plugin.py.
  + Scheduler: Use assertRegexp instead of assertNotRegexp in tests.
  + Scheduler: Use default timeout for assertResponse.
  + Scheduler: Use mocking to make tests faster.
  + Services: Fix typo in doInvite() (#1394)
  + Update core fr translation.
  + Update supybot-plugin-doc to work with current version of the registry.
  + Web: Lower log level when title could not be found.
  + Web: Remove leading space if the prefix is empty.
  + Web: Add early returns on exception when snarfing titles.
  + src/callbacks.py: use network-specific values.
  + test: Don't overwrite the main Schedule in the driver list.
  + test: Mock calls to time.sleep()
  + test: choose a random free port for tests using the HTTP server
* Sun Nov 17 2019 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 2019-11-09:
  + Fix log on SASL failure.
  + Math: Rewrite calc functions with a proper evaluator.
  + Log SASL mechanism on failure. Closes GH-1014.
  + Config: Add : prefix to network-specific values listed by 'config list'.
  + Web: Catch more errors in getTitle.
  + Split 'CAP REQ' commands to not exceed 512 bytes.
  + Reset capability set state on reconnection.
  + Fix conditional on CTCP in urlSnarfer
  + Use a real invalid email in supybot.authors.unknown
  + Don't repeat nick in supybot.Author if nick and name are the same
  + regexp_wrapper: return None instead of False when search times out
* Wed Sep 11 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2019-09-08:
  * Interpret empty server tag values as missing tag values. As
    required by https://ircv3.net/specs/extensions/message-tags
- Changes from version 2019-08-25:
  * Config: Prevent accidental leak of private values on public
    channels.
- Changes from version 2019-07-17:
  * Google: Update for Google's new HTML layout.
* Tue Mar 19 2019 Atri B <badshah400@gmail.com>
- Update to version 2019-02-23:
  * Revert changes to the structure of sdist packages.
  * Fix bugs in wrapping IRC messages.
  * Support for (future) Python 3.8.
  * Fix encoding issue on Python 2.
  * Support [ipv6]:port format.
* Mon Oct 22 2018 badshah400@gmail.com
- Update to version 2018-09-10:
  * Fix Python 3.7 support.
* Tue Aug 28 2018 BArendartchuk@suse.com
- enable Python 2 binaries with update-alternatives: they are
  needed for running legacy plugins
* Fri Aug 17 2018 tchvatal@suse.com
- Drop -devel from deps
* Thu Aug 16 2018 badshah400@gmail.com
- Update to version 2018-06-25-2:
  * test_plugin_create: skip if supybot-plugin-create is not
    installed.
- Changes from version 2018-06-25:
  * Fixes and tests to supybot-plugin-create; modernize the plugin
    template (gh#ProgVal/Limnoria#1340)
  * supybot-plugin-create: compactify import statements in the
    template
  * supybot-plugin-create: prefer importlib over imp on Python >=
    3.4
  * test: add test cases for supybot-plugin-create
  * -plugin-create: fix errors when only a subset of args are
    given
  * -plugin-create: rename --real-name to --author/-a
  * -plugin-create: add -d as an alias to --desc for consistency
* Thu May 10 2018 toddrme2178@gmail.com
- Avoid problem with bytecode being overwritten by tests
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 2018-04-21:
  * Do not break UTF-8 characters in long words. Closes
    gh#ProgVal/Limnoria#1333.
* Wed Apr 18 2018 badshah400@gmail.com
- The gnupg python module is called python{2,3}-python-gnupg,
  adapt Requires accordingly.
* Fri Apr 13 2018 badshah400@gmail.com
- Switch to using PySocks instead of SocksiPy: the former is
  well-maintained than the latter.
* Sat Mar 31 2018 jengelh@inai.de
- Remove empty filler marketing wording from description.
* Wed Feb 21 2018 badshah400@gmail.com
- Enable python2 module [not binaries] since we have
  python2-SocksiPy now.
* Thu Feb 15 2018 badshah400@gmail.com
- Update to master-2018-01-28:
  * NickAuth: Fix NameError caused by e732931.
* Mon Dec 18 2017 badshah400@gmail.com
- Update to master-2017-10-25:
  * Aka: Escape the command in help strings, so they can be
    copy-pasted into @aka add.
- Convert to python single-spec; disable python2 modules as
  python2-SocksiPy is not available.
- Enable tests as part of %%%%check.
* Fri Nov 25 2016 badshah400@gmail.com
- Initial package.
